/**
 * The base class for the different kinds of elements that can be rendered on a
 * Map.
 */
export class MapElement {
    /**
     * Create a new `MapElement`.
     *
     * @param id A value to set as the ID of the `MapElement`.
     */
    constructor(opts) {
        this._active = false;
        this._clickable = true;
        this._id = -1;
        this._name = '';
        this._scale = 1;
        this._visible = true;
        this._zIndex = 1;
        if (opts) {
            this.name = (opts.name !== undefined) ? opts.name : '';
            this.zIndex = (opts.zIndex !== undefined) ? opts.zIndex : 1;
        }
    }
    /**
     * Indicates whether this `MapElement` is currently selected by the user. When
     * active, the `MapElement` is styled differently.  Defaults to `false`.
     */
    set active(isActive) { this._active = isActive; }
    get active() { return this._active; }
    /**
     * Indicates whether this `MapElement` receives mouse and touch events.
     * Defaults to `true`.
     */
    set clickable(isActive) { this._clickable = isActive; }
    get clickable() { return this._clickable; }
    /**
     * The unique identifier for this `MapElement`.
     */
    set id(newId) { this._id = newId; }
    get id() { return this._id; }
    /**
     * The name of this `MapElement`.
     */
    set name(newName) { this._name = newName; }
    get name() { return this._name; }
    /**
     * The scale of this `MapElement`.
     */
    set scale(newScale) { this._scale = newScale; }
    get scale() { return this._scale; }
    /**
     * Indicates if this `MapElement` is currently visible. Defaults to `true`.
     */
    set visible(isVisible) { this._visible = isVisible; }
    get visible() { return this._visible; }
    /**
     * The z-index used to draw this `MapElement`.  Defaults to 1.
     */
    set zIndex(isVisible) { this._zIndex = isVisible; }
    get zIndex() { return this._zIndex; }
}
