import { h } from '@stencil/core';
import { Coordinate } from '../utils/coordinate';
/**
 * An image displayed as the icon of a `MapMarker`.
 */
export class MarkerIcon {
    constructor() {
        this._anchor = new Coordinate(0, 0);
        this._originalSize = { width: 1, height: 1 };
        this._size = { width: 1, height: 1 };
        this._scale = 1;
        this._url = '';
    }
    /**
     * The position of the icon relative to the marker.
     */
    set anchor(c) { this._anchor = c; }
    get anchor() { return this._anchor; }
    /**
     * The natural size of the image without any scaling.
     */
    set originalSize(s) { this._originalSize = s; }
    get originalSize() { return this._originalSize; }
    /**
     * The size of the image after scaling.
     */
    set size(s) { this._size = s; }
    get size() { return this._size; }
    /**
     * The factor by which to scale the image.
     */
    set scale(s) { this._scale = s; }
    get scale() { return this._scale; }
    /**
     * The URL of the image.
     */
    set url(url) { this._url = url; }
    get url() { return this._url; }
    /**
     * Renders the DOM necessary to display the icon.
     */
    render() {
        const t = `translate(${this._anchor.toPathString()}) scale(${this._scale})`;
        return (h("image", { class: "rl-svg__icon", 
            // Don't set width.  Some icons are not square and leaving width
            // unset will set the width automatically while keeping aspect.
            height: this.size.height, transform: t, xlinkHref: this._url }));
    }
}
