import { MDCDialog } from '@material/dialog/index';
import { h } from '@stencil/core';
let nextId = 0;
export class DetailDialog {
    constructor() {
        /**
         * Internal index used to differentiate multiple dialogs.
         */
        this.index = nextId++;
        /**
         * Array of the child `DetailDialogItem` elements.
         */
        this.detailItems = [];
        // @Prop() elementId = -1;
        /**
         * The title of the dialog window.
         */
        this.dialogTitle = 'Detail Dialog';
        /**
         * An array of strings that will be used to create action buttons for the
         * dialog.  When the corresponding button is clicked by the user, MDCDialog
         * will emit an event with the lowercase version of the action. For example
         * the action `Yes` would emit the `MDCDialog:closing` with the property
         * `event.detail.action === 'yes'`.
         */
        this.dialogActions = ['No', 'Yes'];
    }
    componentDidLoad() {
        this.dialog = new MDCDialog(this.root);
    }
    /**
     * Opens this dialog.
     */
    async open() {
        this.dialog.open();
    }
    /**
     * Returns the values of all the DetailDialogItems as an array of
     * `MapElementDetails`
     */
    getDetails() {
        return Promise.all(this.detailItems.map(item => {
            return Promise.all([item.getDetail(), item.toRemove()]).then(values => Promise.resolve(Object.assign({}, values[0], { remove: values[1] })));
        }));
    }
    hostData() {
        return {
            class: {
                'mdc-dialog': true,
                'rl-detail-dialog': true,
            },
            role: 'alertdialog',
            'aria-modal': 'true',
            'aria-labelledby': `rl-detail-dialog__title-${this.index}`,
            'aria-describedby': `rl-detail_dialog__content-${this.index}`
        };
    }
    render() {
        this.detailItems = [];
        return ([
            h("div", { class: "mdc-dialog__container" },
                h("div", { class: "mdc-dialog__surface", style: { width: '60vw', height: '90vh' } },
                    h("h2", { class: "mdc-dialog__title", id: `rl-detail-dialog__title-${this.index}` }, this.dialogTitle),
                    h("div", { class: "mdc-dialog__content", id: `rl-detail-dialog__content-${this.index}` }, this.details && Object.values(this.details).map(detail => h("rl-detail-dialog-item", { detail: detail, categoryOptions: this.categories, ref: el => this.detailItems.push(el) }))),
                    h("button", { type: "button", class: "mdc-button" },
                        h("span", { class: "mdc-button__label", onClick: _ => this.addDetail.emit() }, "Add Detail")),
                    h("footer", { class: "mdc-dialog__actions" }, this.dialogActions.map(action => h("button", { class: "mdc-button mdc-dialog__button", "data-mdc-dialog-action": action.toLowerCase(), type: "button" },
                        h("span", { class: "mdc-button__label" }, action)))))),
            h("div", { class: "mdc-dialog__scrim" }),
        ]);
    }
    static get is() { return "rl-detail-dialog"; }
    static get originalStyleUrls() { return {
        "$": ["detail-dialog.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["detail-dialog.css"]
    }; }
    static get properties() { return {
        "dialogTitle": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The title of the dialog window."
            },
            "attribute": "dialog-title",
            "reflect": false,
            "defaultValue": "'Detail Dialog'"
        },
        "dialogActions": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "string[]",
                "resolved": "string[]",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "An array of strings that will be used to create action buttons for the\ndialog.  When the corresponding button is clicked by the user, MDCDialog\nwill emit an event with the lowercase version of the action. For example\nthe action `Yes` would emit the `MDCDialog:closing` with the property\n`event.detail.action === 'yes'`."
            },
            "defaultValue": "['No', 'Yes']"
        },
        "details": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "MapElementDetailMap",
                "resolved": "MapElementDetailMap | undefined",
                "references": {
                    "MapElementDetailMap": {
                        "location": "import",
                        "path": "../../interface"
                    }
                }
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "The details that will be displayed in this dialog."
            }
        },
        "categories": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "{ name: string, id: number, items: MapElementDetailType[] }[]",
                "resolved": "{ name: string; id: number; items: MapElementDetailType[]; }[]",
                "references": {
                    "MapElementDetailType": {
                        "location": "import",
                        "path": "../../interface"
                    }
                }
            },
            "required": true,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The different categories that each item can display.  Each category has\na set of Detailtypes."
            }
        }
    }; }
    static get events() { return [{
            "method": "addDetail",
            "name": "addDetail",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "An event emitted when a new `DetailDialogItem` is added to the dialog."
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
    static get methods() { return {
        "open": {
            "complexType": {
                "signature": "() => Promise<void>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "Opens this dialog.",
                "tags": []
            }
        },
        "getDetails": {
            "complexType": {
                "signature": "() => Promise<MapElementDetail[]>",
                "parameters": [],
                "references": {
                    "Promise": {
                        "location": "global"
                    },
                    "MapElementDetail": {
                        "location": "import",
                        "path": "../../interface"
                    }
                },
                "return": "Promise<MapElementDetail[]>"
            },
            "docs": {
                "text": "Returns the values of all the DetailDialogItems as an array of\n`MapElementDetails`",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "root"; }
}
