import { MDCSelect } from '@material/select/index';
import { h } from '@stencil/core';
let nextId = 0;
/**
 * A component that wraps a `Material Select Menu` component.
 */
export class Select {
    constructor() {
        /**
         * Internal ID used to differentiate multiple menus.
         */
        this.id = nextId++;
        /**
         * The label displayed on the select.
         */
        this.label = '';
        /**
         * An array of the different options displayed in the select menu.
         */
        this.options = [];
    }
    componentDidLoad() {
        this.select = new MDCSelect(this.root);
        this.select.listen('MDCSelect:change', () => this.selected.emit(this.select.selectedIndex));
    }
    componentDidUnload() {
        this.select.destroy();
    }
    hostData() {
        return {
            class: {
                'mdc-select': true,
            },
        };
    }
    render() {
        return ([
            h("i", { class: "mdc-select__dropdown-icon" }),
            h("select", { class: "mdc-select__native-control" }, this.options.map((option, index) => {
                const o = option.toLowerCase();
                return index === this.selectedOption ?
                    h("option", { value: o, selected: true }, option) :
                    h("option", { value: o }, option);
            })),
            h("label", { class: "mdc-floating-label" }, this.label),
            h("div", { class: "mdc-line-ripple" }),
        ]);
    }
    static get is() { return "rl-select-menu"; }
    static get originalStyleUrls() { return {
        "$": ["select-menu.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["select-menu.css"]
    }; }
    static get properties() { return {
        "label": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The label displayed on the select."
            },
            "attribute": "label",
            "reflect": false,
            "defaultValue": "''"
        },
        "options": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "string[]",
                "resolved": "string[]",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "An array of the different options displayed in the select menu."
            },
            "defaultValue": "[]"
        },
        "selectedOption": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number | undefined",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "The index of the currently selected option or undefined if nothing selected."
            },
            "attribute": "selected-option",
            "reflect": false
        }
    }; }
    static get events() { return [{
            "method": "selected",
            "name": "selected",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "An event emitted when an item is selected.  The detail of the event is set\nto the index of the item selected."
            },
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            }
        }]; }
    static get elementRef() { return "root"; }
}
