var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { f as h } from './rlwc-ca835c31.js';
/**
 * Class for representing coordinates and positions.
 * Adapted from Google Closure Library.
 */
var Coordinate = /** @class */ (function () {
    /**
     * Create a new Coordinate.
     */
    function Coordinate(x, y) {
        this.x = x;
        this.y = y;
    }
    /**
     * Returns a new copy of the coordinate.
     */
    Coordinate.prototype.clone = function () {
        return new Coordinate(this.x, this.y);
    };
    /**
     * Returns a nice string representation the coordinate.
     */
    Coordinate.prototype.toString = function () {
        return '(' + this.x + ', ' + this.y + ')';
    };
    /**
     * Returns a basic string representation of the Coordinate used to easily
     * create SVG path strings.
     */
    Coordinate.prototype.toPathString = function () {
        return this.x + ' ' + this.y;
    };
    /**
     * Returns whether the specified value is equal to this coordinate.
     * @param other Some other value.
     */
    Coordinate.prototype.equals = function (other) {
        return other instanceof Coordinate && Coordinate.equals(this, other);
    };
    /**
     * Rounds the x and y fields to the next larger integer values.
     */
    Coordinate.prototype.ceil = function () {
        this.x = Math.ceil(this.x);
        this.y = Math.ceil(this.y);
        return this;
    };
    /**
     * Rounds the x and y fields to the next smaller integer values.
     */
    Coordinate.prototype.floor = function () {
        this.x = Math.floor(this.x);
        this.y = Math.floor(this.y);
        return this;
    };
    /**
     * Translates this coordinate by the given offsets. If a `Coordinate`
     * is given, then the x and y values are translated by the coordinate's x
     * and y. Otherwise, x and y are translated by `tx` and `ty` respectively.
     *
     * @param tx The value to translate x by or the
     *     the coordinate to translate this coordinate by.
     * @param ty The value to translate y by.
     */
    Coordinate.prototype.translate = function (tx, ty) {
        if (tx instanceof Coordinate) {
            this.x += tx.x;
            this.y += tx.y;
        }
        else {
            this.x += Number(tx);
            if (typeof ty === 'number') {
                this.y += ty;
            }
        }
        return this;
    };
    /**
     * Scales this coordinate by the given scale factors. The x and y values are
     * scaled by `sx` and `sy` respectively.  If `sy` is not given, then `sx` is
     * used for both x and y.
     *
     * @param sx The scale factor to use for the x dimension.
     * @param opt_sy The scale factor to use for the y dimension.
     */
    Coordinate.prototype.scale = function (sx, sy) {
        sy = typeof sy === 'number' ? sy : sx;
        this.x *= sx;
        this.y *= sy;
        return this;
    };
    /**
     * Rotates this coordinate clockwise about the origin (or, optionally, the
     * given center) by the given angle, in radians.
     *
     * @param radians The angle by which to rotate this coordinate
     *     clockwise about the given center, in radians.
     * @param center The center of rotation. Defaults
     *     to (0, 0) if not given.
     */
    Coordinate.prototype.rotateRadians = function (radians, center) {
        center = center || new Coordinate(0, 0);
        var x = this.x;
        var y = this.y;
        var cos = Math.cos(radians);
        var sin = Math.sin(radians);
        this.x = (x - center.x) * cos - (y - center.y) * sin + center.x;
        this.y = (x - center.x) * sin + (y - center.y) * cos + center.y;
        return this;
    };
    /**
     * Rotates this coordinate clockwise about the origin (or, optionally, the
     * given center) by the given angle, in degrees.
     *
     * @param degrees The angle by which to rotate this coordinate
     *     clockwise about the given center, in degrees.
     * @param opt_center The center of rotation. Defaults
     *     to (0, 0) if not given.
     */
    Coordinate.prototype.rotateDegrees = function (degrees, center) {
        return this.rotateRadians(degrees * Math.PI / 180, center);
    };
    /**
     * Restricts each parameter of the Coordinate such that
     * `left <= x <= left + width` and `top <= y <= top + height`.
     *
     * @param limits A rectangle to restrict the Coordinate to.
     */
    Coordinate.prototype.limit = function (limits) {
        // Limit in the x direction.
        var left = !isNaN(limits.left) ? limits.left : undefined;
        var width = !isNaN(limits.width) ? limits.width : 0;
        var maxX = left !== undefined ? left + width : Infinity;
        var minX = left !== undefined ? left : -Infinity;
        this.x = Math.min(maxX, Math.max(minX, this.x));
        // Limit in the y direction.
        var top = !isNaN(limits.top) ? limits.top : undefined;
        var height = !isNaN(limits.height) ? limits.height : 0;
        var maxY = top !== undefined ? top + height : Infinity;
        var minY = top !== undefined ? top : -Infinity;
        this.y = Math.min(maxY, Math.max(minY, this.y));
        return this;
    };
    /**
     * Round the values of the `Coordinate` to a given precision (number of
     * decimals).  Defaults to a precision of 0, or rounding to the nearest
     * integer.
     *
     * @param precision The number of decimals to round to
     */
    Coordinate.prototype.round = function (precision) {
        if (precision === void 0) { precision = 0; }
        var factor = Math.pow(10, precision);
        this.x = Math.round(this.x * factor) / factor;
        this.y = Math.round(this.y * factor) / factor;
        return this;
    };
    /**
     * Compares two `Coordinate`s for equlaity.
     * @param a The first `Coordinate`.
     * @param b The second `Coordinate`.
     */
    Coordinate.equals = function (a, b) {
        if (a === b) {
            return true;
        }
        return a.x === b.x && a.y === b.y;
    };
    /**
     * Returns the distance between two `Coordinate`s.
     * @param a The first `Coordinate`.
     * @param b The second `Coordinate`.
     */
    Coordinate.distance = function (a, b) {
        var dx = a.x - b.x;
        var dy = a.y - b.y;
        return Math.sqrt(dx * dx + dy * dy);
    };
    /**
     * Returns the magnitude (distance from origin) of a `Coordinate`.
     * @param a The first `Coordinate`.
     */
    Coordinate.magnitude = function (a) {
        return Math.sqrt(a.x * a.x + a.y * a.y);
    };
    /**
     * Returns the squared distance between two `Coordinate`s. Squared distances
     * can be used for comparisons when the actual value is not required.
     *
     * Performance note: eliminating the square root is an optimization often used
     * in lower-level languages, but the speed difference is not nearly as
     * pronounced in JavaScript (only a few percent.)
     *
     * @param a The first `Coordinate`.
     * @param b The second `Coordinate`.
     */
    Coordinate.squareDistance = function (a, b) {
        var dx = a.x - b.x;
        var dy = a.y - b.y;
        return dx * dx + dy * dy;
    };
    /**
     * Returns the difference between two `Coordinate`s.
     * @param a The first `Coordinate`.
     * @param b The second `Coordinate`.
     */
    Coordinate.difference = function (a, b) {
        if (!b) {
            return new Coordinate(0, 0);
        }
        return new Coordinate(a.x - b.x, a.y - b.y);
    };
    /**
     * Returns the sum of two coordinates as a new `Coordinate`.
     * @param a The first `Coordinate`.
     * @param b The second `Coordinate`.
     */
    Coordinate.sum = function (a, b) {
        return new Coordinate(a.x + b.x, a.y + b.y);
    };
    /**
     * Returns the midpoint of two coordinates as a new `Coordinate`.
     * @param a The first `Coordinate`.
     * @param b The second `Coordinate`.
     */
    Coordinate.midpoint = function (a, b) {
        return new Coordinate((a.x + b.x) / 2, (a.y + b.y) / 2);
    };
    return Coordinate;
}());
/**
 * Returns the position of the event or the element's border box relative to
 * the client viewport. If an event is passed, and if this event is a "touch"
 * event, then the position of the first changedTouches will be returned.
 *
 * @param el Element or a mouse / touch event.
 * @return The position.
 */
function getClientPosition(el) {
    if (el.nodeType === 1 /* NodeType ELEMENT */) {
        return getClientPositionForElement_(el);
    }
    else {
        var targetEvent = el.changedTouches ? el.changedTouches[0] : el;
        return new Coordinate(targetEvent.clientX, targetEvent.clientY);
    }
}
/**
 * Returns the position of the event or the element's border box relative to
 * the client viewport.
 *
 * @param el Element whose position to get.
 * @return The position.
 */
function getClientPositionForElement_(el) {
    var box = getBoundingClientRect_(el);
    return new Coordinate(box.left, box.top);
}
/**
 * Gets the client rectangle of the DOM element.
 *
 * getBoundingClientRect is part of a new CSS object model draft (with a
 * long-time presence in IE), replacing the error-prone parent offset
 * computation and the now-deprecated Gecko getBoxObjectFor.
 *
 * This utility patches common browser bugs in getBoundingClientRect. It
 * will fail if getBoundingClientRect is unsupported.
 *
 * If the element is not in the DOM, the result is undefined, and an error may
 * be thrown depending on user agent.
 *
 * @param el The element whose bounding rectangle is being queried.
 * @return A native bounding rectangle with numerical left, top,
 *     right, and bottom.  Reported by Firefox to be of object type ClientRect.
 */
function getBoundingClientRect_(el) {
    var rect;
    try {
        rect = el.getBoundingClientRect();
    }
    catch (e) {
        // In IE < 9, calling getBoundingClientRect on an orphan element raises an
        // "Unspecified Error". All other browsers return zeros.
        return { 'left': 0, 'top': 0, 'right': 0, 'bottom': 0 };
    }
    return rect;
}
/**
 * Creates a new Coordinate based on the clientX/Y values of a given event or the
 * top-left corner of an element.  Optionally gets the position relative to a
 * second element.
 *
 * @param e The event to retrieve the client coordinates from.
 */
function coordinateFromEvent(a, b) {
    var ap = getClientPosition(a);
    var bp = getClientPosition(b);
    return new Coordinate(ap.x - bp.x, ap.y - bp.y);
}
/**
 * Parses a string of x/y coordinate pairs separated by spaces.  Returns an
 * object with two properties.  The `points` property is an array of Coordinate
 * objects representing each x/y pair and the `path` property is an SVG encoded
 * path string in the form `M x1 y1 L x2 y2 ... L xN yN Z`.
 *
 * @param data A string of space-separated coordinates.
 */
function decodeCoordinates(data, closed) {
    var pointData = data.split(' ');
    var points = [];
    var i = pointData.length - 2;
    var x;
    var y;
    // Closed paths end with 'Z'. Start with that and work backwards unless open.
    var path = closed ? 'Z' : '';
    while (i >= 0) {
        x = Math.round(Number(pointData[i]));
        y = Math.round(Number(pointData[i + 1]));
        points.push(new Coordinate(x, y));
        path = (i === 0 ? ['M', x, y, path].join(' ') : ['L', x, y, path].join(' '));
        i -= 2;
    }
    if (points.length === 1) {
        points = points[0];
    }
    return { path: path, points: points };
}
/**
 * Turns an array of Coordinate objects into a single space-separated string.
 * @param points An array of Coordinates.
 */
function encodeCoordinates(points) {
    if (points instanceof Coordinate) {
        return points.toPathString();
    }
    else {
        return points.map(function (i) {
            return i.toPathString();
        }).join(' ');
    }
}
/**
 * Generates an SVG-style path string from an array of `Coordinates`.
 *
 * @param points An array of `Coordinates`.
 * @param open If the path represented by the array of points is open or closed.
 */
function pathFromCoordinateArray(points, open) {
    if (open === void 0) { open = false; }
    return points.map(function (i, idx) {
        if (idx === 0) {
            return 'M ' + i.toPathString();
        }
        else if (idx === points.length - 1 && !open) {
            return ' L ' + i.toPathString() + ' Z';
        }
        else {
            return ' L ' + i.toPathString();
        }
    }).join('');
}
/**
 * The base class for the different kinds of elements that can be rendered on a
 * Map.
 */
var MapElement = /** @class */ (function () {
    /**
     * Create a new `MapElement`.
     *
     * @param id A value to set as the ID of the `MapElement`.
     */
    function MapElement(opts) {
        this._active = false;
        this._clickable = true;
        this._id = -1;
        this._name = '';
        this._scale = 1;
        this._visible = true;
        this._zIndex = 1;
        if (opts) {
            this.name = (opts.name !== undefined) ? opts.name : '';
            this.zIndex = (opts.zIndex !== undefined) ? opts.zIndex : 1;
        }
    }
    Object.defineProperty(MapElement.prototype, "active", {
        get: function () { return this._active; },
        /**
         * Indicates whether this `MapElement` is currently selected by the user. When
         * active, the `MapElement` is styled differently.  Defaults to `false`.
         */
        set: function (isActive) { this._active = isActive; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapElement.prototype, "clickable", {
        get: function () { return this._clickable; },
        /**
         * Indicates whether this `MapElement` receives mouse and touch events.
         * Defaults to `true`.
         */
        set: function (isActive) { this._clickable = isActive; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapElement.prototype, "id", {
        get: function () { return this._id; },
        /**
         * The unique identifier for this `MapElement`.
         */
        set: function (newId) { this._id = newId; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapElement.prototype, "name", {
        get: function () { return this._name; },
        /**
         * The name of this `MapElement`.
         */
        set: function (newName) { this._name = newName; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapElement.prototype, "scale", {
        get: function () { return this._scale; },
        /**
         * The scale of this `MapElement`.
         */
        set: function (newScale) { this._scale = newScale; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapElement.prototype, "visible", {
        get: function () { return this._visible; },
        /**
         * Indicates if this `MapElement` is currently visible. Defaults to `true`.
         */
        set: function (isVisible) { this._visible = isVisible; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapElement.prototype, "zIndex", {
        get: function () { return this._zIndex; },
        /**
         * The z-index used to draw this `MapElement`.  Defaults to 1.
         */
        set: function (isVisible) { this._zIndex = isVisible; },
        enumerable: true,
        configurable: true
    });
    return MapElement;
}());
/**
 * Predefined map Symbols.
 */
var MarkerSymbolPaths;
(function (MarkerSymbolPaths) {
    MarkerSymbolPaths["computer"] = "M 8 36 c -2 0 -4 -2 -4 -4 v -20 c 0 -2 2 -4 4 -4 h 32 c 2 0 4 2 4 4 v 20 c 0 2 -2 4 -4 4 h 8 v 4 h -48 v -4 z M 8 12 h 32 v 20 h -32 z";
})(MarkerSymbolPaths || (MarkerSymbolPaths = {}));
/**
 * A styled vector path displayed as the icon of a `MapMarker`.
 */
var MarkerSymbol = /** @class */ (function () {
    function MarkerSymbol() {
        this._alt = false;
        this._anchor = new Coordinate(0, 0);
        this._path = '';
        /**
         * The name of the path.  This is appended to the class added to the path and
         * allows for custom styling based on each type of path.
         */
        this._pathName = '';
        this._rotation = 0;
        this._size = { width: 1, height: 1 };
    }
    Object.defineProperty(MarkerSymbol.prototype, "alt", {
        get: function () { return this._alt; },
        /**
         * A flag indicating if this symbol should use an alternate style.
         */
        set: function (a) { this._alt = a; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerSymbol.prototype, "anchor", {
        get: function () { return this._anchor; },
        /**
         * The position of the symbol relative to the marker.
         */
        set: function (c) { this._anchor = c; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerSymbol.prototype, "path", {
        get: function () { return this._path; },
        /**
         * The symbol's path specified using a built-in string or a custom path
         * expressed using SVG path notation.
         */
        set: function (p) {
            // If supplied path is a string matching the name of a key of MarkerSymbolPaths,
            // set the path to that, otherwise just p. No check if string is valid SVG
            // path.
            if (p in MarkerSymbolPaths) {
                this._pathName = p;
                this._path = MarkerSymbolPaths[p];
            }
            else {
                this._pathName = 'custom';
                this._path = p;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerSymbol.prototype, "rotation", {
        get: function () { return this._rotation; },
        /**
         * The angle by which to rotate the symbol, expressed clockwise in degrees.
         */
        set: function (r) { this._rotation = r % 360; } // Clamp to [0,360]
        ,
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerSymbol.prototype, "size", {
        get: function () { return this._size; },
        /**
         * The size of the symbol
         */
        set: function (s) { this._size = s; },
        enumerable: true,
        configurable: true
    });
    /**
     * Renders the DOM necessary to display this symbol.
     */
    MarkerSymbol.prototype.render = function () {
        var sx = this._size.width / 48;
        var sy = this._size.height / 48;
        var tr = this._anchor.toPathString();
        var ro = this._rotation;
        var t = "translate(" + tr + ") rotate(" + ro + ") scale(" + sx + ", " + sy + ")";
        var pathClass = {
            'rl-svg__symbol': true,
        };
        pathClass["rl-svg__symbol--" + this._pathName] = true;
        pathClass["rl-svg__symbol--" + this._pathName + "-alt"] = this._alt;
        return (h("path", { class: pathClass, transform: t, d: this._path }));
    };
    return MarkerSymbol;
}());
var CONTROL_SIZE = 72;
/**
 * A type of `MapElement`.  A marker is an image or text rendered at a specific
 * point on a Map.
 */
var MapMarker = /** @class */ (function (_super) {
    __extends(MapMarker, _super);
    function MapMarker(opts) {
        var _this = _super.call(this, opts) || this;
        _this._anchor = new Coordinate(0, 0);
        _this._available = false;
        _this._label = '';
        _this._opacity = 1;
        _this._position = new Coordinate(0, 0);
        if (opts) {
            _this.anchor = opts.anchor ? opts.anchor : new Coordinate(0, 0);
            _this.available = opts.available ? opts.available : false;
            _this.icon = opts.icon ? opts.icon : undefined;
            _this.label = (opts.label !== undefined) ? opts.label : '';
            _this.opacity = (opts.opacity !== undefined) ? opts.opacity : 1;
            _this.position = opts.position;
        }
        return _this;
    }
    Object.defineProperty(MapMarker.prototype, "anchor", {
        get: function () { return this._anchor; },
        /**
         * An offset relative to the `position` of the marker.
         */
        set: function (newAnchor) { this._anchor = newAnchor; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapMarker.prototype, "available", {
        get: function () { return this._available; },
        /**
         * A flag indicating if the this `MapMarker` represents an active or inactive
         * point.  When the marker is available, it gets a matching `--available` CSS
         * class added.
         */
        set: function (isAvailable) { this._available = isAvailable; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapMarker.prototype, "icon", {
        get: function () { return this._icon; },
        /**
         * The icon that will be drawn for this `MapMarker`.
         */
        set: function (newIcon) { this._icon = newIcon; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapMarker.prototype, "label", {
        get: function () { return this._label; },
        /**
         * A line of text dispayed on the map either on its own as a simple text
         * label or along side the `icon`.
         */
        set: function (newLabel) { this._label = newLabel; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapMarker.prototype, "opacity", {
        get: function () { return this._opacity; },
        /**
         * The opacity of the marker, 1 being fully opaque and 0 being fully
         * transparent.
         */
        set: function (newOpacity) { this._opacity = Math.max(0, Math.min(1, newOpacity)); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapMarker.prototype, "position", {
        get: function () { return this._position; },
        /**
         * The overall position of the marker on the `Map`.
         */
        set: function (newPosition) { this._position = newPosition; },
        enumerable: true,
        configurable: true
    });
    /**
     * Moves this marker by a given amount.
     * @param delta The amount to move by
     */
    MapMarker.prototype.move = function (delta) {
        this._position.translate(delta);
    };
    MapMarker.prototype.render = function () {
        if (!this.visible || this._id === -1 &&
            this._position.equals(new Coordinate(0, 0))) {
            return undefined;
        }
        var rectClass = {
            'rl-svg__rect': true,
            'rl-svg__rect--activated': this.active,
        };
        var contents = [];
        var rect = (h("rect", { class: rectClass, rx: "12", ry: "12", height: CONTROL_SIZE, width: CONTROL_SIZE }));
        if (this._icon === undefined) {
            if (this._label !== '') {
                contents.push((h("text", { y: CONTROL_SIZE - 11, x: CONTROL_SIZE / 2 }, this._label)));
            }
        }
        else {
            this._icon.size = { width: CONTROL_SIZE, height: CONTROL_SIZE };
            if (this._icon instanceof MarkerSymbol) {
                this._icon.alt = this._available;
            }
            contents.push(this._icon.render());
        }
        contents.push(rect);
        var gTrans = "translate(" + this.position.toPathString() + ")";
        var gClass = {
            'rl-svg__marker': true,
            'rl-svg__marker--clickable': this._clickable,
        };
        return (h("g", { id: "" + this._id, class: gClass, tabIndex: this._clickable ? 0 : undefined, transform: gTrans }, contents));
    };
    return MapMarker;
}(MapElement));
/**
 * A type of `MapElement`.  A polygon is a shape drawn onto a `Map` based on a
 * path consisting of three or more `Coordinates`.
 */
var MapPolygon = /** @class */ (function (_super) {
    __extends(MapPolygon, _super);
    function MapPolygon() {
        var _this = _super.apply(this, arguments) || this;
        _this._open = false;
        /**
         * A string in SVG Path notation used to draw this `MapPolygon`.
         */
        _this._path = '';
        _this._points = [];
        return _this;
    }
    Object.defineProperty(MapPolygon.prototype, "open", {
        get: function () { return this._open; },
        /**
         * If set to true, this `MapPolygon` is not automatically closed.
         */
        set: function (open) {
            this._open = open;
            this._path = pathFromCoordinateArray(this._points, open);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MapPolygon.prototype, "points", {
        get: function () { return this._points; },
        /**
         * An array of `Coordinate`s that correspond to the points of this `MapPolygon`.
         */
        set: function (newPoint) {
            this._points = newPoint;
            this._path = pathFromCoordinateArray(newPoint, this._open);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Add a new point to the array of points that represent this `MapRegion`.
     * @param c The `Coordinate` representing the point to add
     * @param index The index where the point should be added.  If not specified,
     * adds the point at the end
     */
    MapPolygon.prototype.addPoint = function (c, index) {
        var pts = this._points;
        this.points = index !== undefined ? pts.slice(0, index).concat([c], pts.slice(index)) : pts.concat([c]);
    };
    /**
     * Move this `MapRegion` by a specified offset.
     * @param delta The amount to move by
     */
    MapPolygon.prototype.move = function (delta) {
        var p = this.points;
        p.forEach(function (c) { return c.translate(delta); });
        this.points = p.slice();
    };
    /**
     * Move a single point of this `MapRegion` by a specified amount.
     * @param delta The amount to move by
     * @param index The index of the point to move
     */
    MapPolygon.prototype.movePoint = function (delta, index) {
        var p = this.points;
        p[index].translate(delta);
        this.points = p.slice();
        // this.points = arrayReplace(p, index, p[index].translate(delta));
    };
    /**
     * Remove a point from the array of points that represent this `MapRegion`.
     * If no index is specified, the last point is removed.
     * @param index The index of the point to remove
     */
    MapPolygon.prototype.removePoint = function (index) {
        var p = this._points;
        if (index !== undefined) {
            p.splice(index, 1);
        }
        else {
            p.splice(p.length - 1, 1);
        }
        this.points = p.slice();
    };
    /**
     * Renders the `MapPolygon`.
     */
    MapPolygon.prototype.render = function () {
        if (this._visible === false) {
            return undefined;
        }
        var classname = {
            'rl-svg__polygon': true,
            'rl-svg__polygon--activated': this._active && !this._open,
            'rl-svg__polygon--open': this._open,
        };
        return (h("g", { id: "" + this._id, class: classname }, h("path", { d: this._path, tabIndex: 0, "aria-label": this._name, role: "button" })));
    };
    /**
     * Generates the DOM necessary to display the control points for this
     * `MapElement`.  There are control points at the median and endpoint of each
     * edge.  This allows any point of the `MapElement` to be moved as well as new
     * point created on each line.
     */
    MapPolygon.prototype.renderControls = function () {
        var _this = this;
        // if (!this._active && !this._open) {
        //   return undefined;
        // }
        var pts = this._points;
        // If there are no points, or element is not visible, don't render controls.
        if (this._visible === false || pts.length === 0) {
            return undefined;
        }
        // Create a control for each point.  Don't create a control for the last
        // point of an open path though.
        var points = pts.filter(function (_, idx) { return (pts.length === 1 || (_this._open && idx === pts.length - 1 ? false : true)); }).map(function (i, index) {
            var controls = [(h("circle", { cx: i.x, cy: i.y, r: 8 / _this._scale, "data-index": index * 2, class: "rl-svg__control" }))];
            // Create a midpoint control.  This allows an edge segment to be split.
            if (!_this._open) {
                var mid = (index === pts.length - 1) ?
                    Coordinate.midpoint(i, pts[0]) :
                    Coordinate.midpoint(i, pts[index + 1]);
                controls.push((h("circle", { cx: mid.x, cy: mid.y, r: 8 / _this._scale, "data-index": index * 2 + 1, class: "rl-svg__midpoint" })));
            }
            return controls;
        });
        // Render an additional line to 'connect the dots' of the control points.
        var path = (h("path", { class: "rl-svg__polygon-outline", d: pathFromCoordinateArray(pts, this._open) }));
        return [path, points];
    };
    return MapPolygon;
}(MapElement));
/**
 * An image displayed as the icon of a `MapMarker`.
 */
var MarkerIcon = /** @class */ (function () {
    function MarkerIcon() {
        this._anchor = new Coordinate(0, 0);
        this._originalSize = { width: 1, height: 1 };
        this._size = { width: 1, height: 1 };
        this._scale = 1;
        this._url = '';
    }
    Object.defineProperty(MarkerIcon.prototype, "anchor", {
        get: function () { return this._anchor; },
        /**
         * The position of the icon relative to the marker.
         */
        set: function (c) { this._anchor = c; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerIcon.prototype, "originalSize", {
        get: function () { return this._originalSize; },
        /**
         * The natural size of the image without any scaling.
         */
        set: function (s) { this._originalSize = s; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerIcon.prototype, "size", {
        get: function () { return this._size; },
        /**
         * The size of the image after scaling.
         */
        set: function (s) { this._size = s; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerIcon.prototype, "scale", {
        get: function () { return this._scale; },
        /**
         * The factor by which to scale the image.
         */
        set: function (s) { this._scale = s; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MarkerIcon.prototype, "url", {
        get: function () { return this._url; },
        /**
         * The URL of the image.
         */
        set: function (url) { this._url = url; },
        enumerable: true,
        configurable: true
    });
    /**
     * Renders the DOM necessary to display the icon.
     */
    MarkerIcon.prototype.render = function () {
        var t = "translate(" + this._anchor.toPathString() + ") scale(" + this._scale + ")";
        return (h("image", { class: "rl-svg__icon",
            // Don't set width.  Some icons are not square and leaving width
            // unset will set the width automatically while keeping aspect.
            height: this.size.height, transform: t, xlinkHref: this._url }));
    };
    return MarkerIcon;
}());
var HYSTERESIS = 8;
// Default maximum scale (zoom) factor.
var DEFAULT_MAX_SCALE = 3;
// Default minimum scale (zoom) factor.
var DEFAULT_MIN_SCALE = 1;
// The different states the Map/MapEditor can be in.
var STATES = {
    NORMAL: 0,
    GESTURE_DOWN: 1,
    DRAGGING: 2,
    ZOOMING: 3,
    ADD_REGION_INIT: 10,
    ADD_REGION_FIRST: 11,
    ADD_REGION: 12,
    ADD_POINT: 20,
    DRAG_ELEMENT: 30,
};
function computeLimits(iSize, sSize, scale) {
    return new DOMRect(Math.min(0, sSize.width - iSize.width * scale), // left / x
    Math.min(0, sSize.height - iSize.height * scale), // top / y
    Math.abs(iSize.width * scale - sSize.width), // width
    Math.abs(iSize.height * scale - sSize.height) // height
    );
}
/**
 * Gets the ID of a given Element within the Map SVG.  This makes use of the
 * known DOM structure of the SVG.
 * @param el The Element to use to find the ID.
 */
function getTargetId(el) {
    if (el instanceof SVGImageElement || el instanceof SVGRectElement ||
        el instanceof SVGPathElement || el instanceof SVGTextElement) {
        // The image (symbol), bounding rectangle, text or path were clicked.
        // In these cases, the parent (group) tag holds the ID.
        el = el.parentElement;
    }
    if (el instanceof SVGGElement) {
        return Number(el.id);
    }
    return undefined;
}
/**
 * Processes an array of `MapElement`s, turning them into an array of
 * `ParsedMapElement` objects.  These parsed map elements are then rendered onto
 * a map.
 * @param elements An array of `MapElement`s to process
 * @param scale The scale applied to the `ParsedElement`
 */
function parseElements(elements, scale) {
    if (scale === void 0) { scale = 1; }
    return Object.values(elements).map(function (el) {
        var decoded = decodeCoordinates(el.points, true);
        var icon;
        if (typeof el.icon === 'string') {
            icon = new MarkerIcon();
            icon.url = el.icon;
        }
        else if (el.symbol !== undefined && el.symbol in MarkerSymbolPaths) {
            icon = new MarkerSymbol();
            icon.path = el.symbol;
        }
        var newEl;
        if (decoded.points instanceof Coordinate) {
            newEl = new MapMarker();
            newEl.icon = icon;
            newEl.position = decoded.points;
            newEl.label = (typeof el.icon !== 'string' && typeof el.symbol !== 'string') ? el.name : '';
            newEl.available = el.available || false;
        }
        else {
            newEl = new MapPolygon();
            newEl.points = decoded.points;
        }
        newEl.id = el.id;
        newEl.name = el.name;
        newEl.visible = el.enabled;
        newEl.scale = scale;
        newEl.clickable = el.clickable !== undefined ? el.clickable : true;
        return newEl;
    });
}
export { STATES as a, Coordinate as b, DEFAULT_MAX_SCALE as c, DEFAULT_MIN_SCALE as d, parseElements as e, coordinateFromEvent as f, getTargetId as g, HYSTERESIS as h, computeLimits as i, MapPolygon as j, MapMarker as k, encodeCoordinates as l };
