import { d as registerInstance, f as h, h as Host } from './rlwc-ca835c31.js';
var nextId = 0;
/**
 * An entry to be displayed as part of a `DetailDialog`.
 */
var DetailDialogItem = /** @class */ (function () {
    function DetailDialogItem(hostRef) {
        registerInstance(this, hostRef);
        this.index = nextId++;
        this.itemId = 0;
        /**
         * A flag indicating that this item will be removed when all the details are
         * serialized and sent to the server.
         */
        this.remove = false;
        /**
         * The description for this item.
         */
        this.description = '';
        /**
         * The name of this item.
         */
        this.name = '';
        /**
         * Alternate text for this item.
         */
        this.altText = '';
        /**
         * The ID of the detail type of this item.
         */
        this.detailTypeId = -1;
        /**
         * The short code of this item.
         */
        this.code = '';
        /**
         * The currently selected category.
         */
        this.categorySelection = 0;
        /**
         * All the possible values for the type of this `DetailDialogItem`.
         */
        this.typeOptions = [];
        /**
         * The currently selected item Type.
         */
        this.typeSelection = 0;
    }
    DetailDialogItem.prototype.onDetailChanged = function () {
        var _this = this;
        if (this.detail) {
            this.description = this.detail.description;
            this.name = this.detail.name;
            this.altText = this.detail.altText;
            this.itemId = this.detail.id;
            this.detailTypeId = this.detail.detailTypeId;
            this.code = this.detail.code;
            if (this.detail.detailTypeId > 0) {
                // Set the selected category and detailType to match.
                this.categoryOptions.forEach(function (c, cidx) {
                    c.items.forEach(function (dt, dtidx) {
                        if (_this.detailTypeId === dt.id) {
                            _this.updateCategory(cidx);
                            _this.typeSelection = dtidx; // { ...dt };
                        }
                    });
                });
            }
        }
    };
    DetailDialogItem.prototype.onCategoryOptionsChanged = function () {
        this.updateCategory(0);
    };
    DetailDialogItem.prototype.updateCategory = function (newIndex) {
        this.categorySelection = newIndex;
        this.typeOptions = this.categoryOptions[newIndex].items;
        this.typeSelection = 0;
    };
    DetailDialogItem.prototype.componentWillLoad = function () {
        // If categories have already been provided, set the types options to the
        // items of the first category, as that is selected by default.
        this.typeOptions = this.categoryOptions[0].items;
    };
    DetailDialogItem.prototype.componentDidLoad = function () {
        this.updateCategory(this.categorySelection);
        this.onDetailChanged();
    };
    /**
     * Returns a `Promise` that resolves to a `MapElementDetail` object with
     * values set as those of this `DetailDialogItem`.
     */
    DetailDialogItem.prototype.getDetail = function () {
        return Promise.resolve({
            description: this.description,
            name: this.name,
            code: this.code,
            altText: this.altText,
            id: this.itemId,
            detailTypeId: this.typeOptions[this.typeSelection].id,
        });
    };
    /**
     * Returns a `Promise` that resolves to whether or not this `DetailDialogItem`
     * is to be removed or not.
     */
    DetailDialogItem.prototype.toRemove = function () {
        return Promise.resolve(this.remove);
    };
    DetailDialogItem.prototype.hostData = function () {
        return {
            class: {
                'rl-detail-dialog-item': true,
                'rl-detail-dialog-item--removed': this.remove,
            },
            id: "rl-detail-dialog-item-" + this.index
        };
    };
    DetailDialogItem.prototype.__stencil_render = function () {
        var _this = this;
        // if (this.categorySelection === undefined || this.typeSelection === undefined || this.remove) {
        //   return null;
        // }
        return ([
            h("div", { class: "rl-text-field-container" }, h("rl-select-menu", { label: "Category", options: this.categoryOptions.map(function (c) { return c.name; }), selectedOption: this.categorySelection, onSelected: function (evt) {
                    var categories = _this.categoryOptions[evt.detail];
                    _this.updateCategory(evt.detail);
                    // this.categorySelection = evt.detail;
                    _this.typeOptions = categories.items.slice();
                    _this.typeSelection = 0;
                } })),
            h("div", { class: "rl-text-field-container" }, h("rl-select-menu", { label: "Type", options: this.typeOptions.map(function (i) { return i.name; }), selectedOption: this.typeSelection, onSelected: function (evt) {
                    _this.typeSelection = evt.detail;
                } })),
            h("div", { class: "rl-text-field-container" }, h("rl-text-field", { label: "Code", value: this.code, onChangeValue: function (e) { return _this.code = e.detail; } })),
            h("div", { class: "rl-text-field-container" }, h("rl-text-field", { label: "Name", value: this.name, onChangeValue: function (e) { return _this.name = e.detail; } })),
            h("div", { class: "rl-text-field-container" }, h("rl-text-field", { label: "Description", value: this.description, onChangeValue: function (e) { return _this.description = e.detail; } })),
            h("div", { class: "rl-text-field-container" }, h("rl-text-field", { label: "Alt Text", value: this.altText, onChangeValue: function (e) { return _this.altText = e.detail; } })),
            h("button", { type: "button", class: "mdc-button" }, h("span", { class: "mdc-button__label", onClick: function (_) { return _this.remove = true; } }, "Remove"))
        ]);
    };
    Object.defineProperty(DetailDialogItem, "watchers", {
        get: function () {
            return {
                "detail": ["onDetailChanged"],
                "categoryOptions": ["onCategoryOptionsChanged"]
            };
        },
        enumerable: true,
        configurable: true
    });
    DetailDialogItem.prototype.render = function () { return h(Host, this.hostData(), this.__stencil_render()); };
    Object.defineProperty(DetailDialogItem, "style", {
        get: function () { return ".rl-detail-dialog-item{-webkit-box-shadow:0 3px 1px -2px rgba(0,0,0,.2),0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12);box-shadow:0 3px 1px -2px rgba(0,0,0,.2),0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12);display:block;margin:16px;padding:8px;border-radius:4px}.rl-detail-dialog-item .rl-text-field-container{display:block}.rl-detail-dialog-item--removed{display:none;visibility:hidden}"; },
        enumerable: true,
        configurable: true
    });
    return DetailDialogItem;
}());
export { DetailDialogItem as rl_detail_dialog_item };
