var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { d as registerInstance, e as createEvent, f as h, g as getElement, h as Host } from './rlwc-ca835c31.js';
import { a as STATES, b as Coordinate, c as DEFAULT_MAX_SCALE, d as DEFAULT_MIN_SCALE, e as parseElements, f as coordinateFromEvent, j as MapPolygon, g as getTargetId, h as HYSTERESIS, k as MapMarker, l as encodeCoordinates, i as computeLimits } from './chunk-dd9ee2fa.js';
var RLMapEditor = /** @class */ (function () {
    function RLMapEditor(hostRef) {
        registerInstance(this, hostRef);
        /**
         * The original scale factor used to size the SVG so it fits into the SVG and
         * covers the entire SVG.
         */
        this.initialScale = 1;
        /**
         * The array of MapElements currently being displayed.  Created from the
         * `elements` Prop with additional internal information added.
         */
        this.processedElements = [];
        /**
         * The current state of the Map.
         */
        this.state = STATES.NORMAL;
        /**
         * Flag indicating if the map image has loaded or not.
         */
        this.imageLoaded = false;
        /**
         * The current size of the SVG element used to display the map.
         */
        this.size = { width: 1, height: 1 };
        /**
         * The factor by which the Map contents are changed to fit within the SVG.
         */
        this.svgScale = 1;
        /**
         * The x,y translation applied to move the map contents within the bounds of
         * the SVG.
         */
        this.svgTransform = new Coordinate(0, 0);
        /**
         * An array of the elements that will be displayed on the Map.
         */
        this.elements = {};
        /**
         *  The maximum scale factor.
         */
        this.maxScale = DEFAULT_MAX_SCALE;
        /**
         * The minimum scale factor.
         */
        this.minScale = DEFAULT_MIN_SCALE;
        this.elementCreated = createEvent(this, "elementCreated", 7);
        this.elementDeselected = createEvent(this, "elementDeselected", 7);
        this.elementSelected = createEvent(this, "elementSelected", 7);
        this.elementUpdated = createEvent(this, "elementUpdated", 7);
        this.elementDeleted = createEvent(this, "elementDeleted", 7);
        this.elementDoubleClicked = createEvent(this, "elementDoubleClicked", 7);
    }
    /**
     * Handle when the list of specified elements changes. The event details
     * contains the `MapElement` that was deleted.
     */
    RLMapEditor.prototype.onElementsChanged = function () {
        // if (this.elements !== undefined) {
        this.processedElements = parseElements(this.elements, this.svgScale);
        // }
    };
    RLMapEditor.prototype.onMapImageChanged = function () {
        var _this = this;
        if (this.mapImage === undefined) {
            return;
        }
        var img = new Image();
        img.src = this.mapImage;
        this.imageLoaded = false;
        img.onload = function () {
            _this.imageLoaded = true;
            if (_this.imgSize &&
                _this.imgSize.width === img.width &&
                _this.imgSize.height === img.height) {
                return;
            }
            _this.imgSize = { width: img.width, height: img.height };
            _this.computeScale();
            _this.limits = _this.computeLimits();
        };
    };
    RLMapEditor.prototype.componentDidLoad = function () {
        this.onMapImageChanged();
        this.onElementsChanged();
        this.onResize();
    };
    /**
     * Handles when the user triggers a touch/down event to start interaction with
     * the map.
     * @param e The triggering event.
     */
    RLMapEditor.prototype.onGestureDown = function (e) {
        this.start = this.last = coordinateFromEvent(e, this.root);
        if (this.state === STATES.NORMAL) {
            this.state = STATES.GESTURE_DOWN;
        }
        if (this.state === STATES.ADD_REGION_INIT) {
            if (this.activeElement && this.activeElement instanceof MapPolygon) {
                this.activeElement.addPoint(this.toSvgSpace(this.start));
                this.root.forceUpdate();
            }
            this.state = STATES.ADD_REGION_FIRST;
        }
        else if (this.state !== STATES.ADD_POINT) {
            // Get the ID of the event target, if it is the correct type.
            var id_1 = getTargetId(e.target);
            if (id_1 !== undefined) {
                this.targetElement = this.processedElements.find(function (i) { return i.id === id_1; });
            }
            if (e.target && e.target instanceof SVGCircleElement) {
                if (e.target.classList.contains('rl-svg__control') ||
                    e.target.classList.contains('rl-svg__midpoint')) {
                    this.targetControl = Number(e.target.dataset.index);
                }
            }
        }
    };
    /**
     * Handles when the user triggers a movement event.
     * @param e The triggering event.
     */
    RLMapEditor.prototype.onGestureMove = function (e) {
        if (this.state === STATES.NORMAL || this.state === STATES.ADD_REGION_INIT) {
            return;
        }
        // Convert the coordinate to SVG coordinate space.
        var point = coordinateFromEvent(e, this.root);
        var delta = Coordinate.difference(point, this.last);
        var dist = 0;
        switch (this.state) {
            case STATES.GESTURE_DOWN:
                if (this.start && (this.targetControl !== undefined || this.activeElement && this.targetElement === this.activeElement)) {
                    dist = Coordinate.squareDistance(this.start, point);
                    if (dist > HYSTERESIS) {
                        this.state = STATES.DRAGGING;
                    }
                    break;
                }
            case STATES.DRAGGING:
                if (this.targetControl !== undefined && this.activeElement !== undefined && this.activeElement instanceof MapPolygon) {
                    if (this.targetControl % 2 === 1) {
                        // If the target control is a midpoint, Add it to the array of
                        // controls.
                        var i = Math.floor(this.targetControl / 2) + 1;
                        this.activeElement.addPoint(Coordinate.difference(this.toSvgSpace(point), this.toSvgSpace(this.svgTransform)), i);
                        // Update the targetControl to be the index of the new control.
                        this.targetControl = i * 2;
                    }
                    else {
                        this.activeElement.movePoint(this.toSvgScale(delta), this.targetControl / 2);
                        this.root.forceUpdate();
                    }
                }
                else if (this.targetElement && this.activeElement &&
                    this.activeElement.id === this.targetElement.id) {
                    this.targetElement.move(this.toSvgScale(delta));
                    this.root.forceUpdate();
                }
                else {
                    // Move the canvas otherwise.
                    if (this.limits !== undefined) {
                        this.state = STATES.DRAGGING;
                        this.svgTransform = Coordinate.sum(this.svgTransform, delta).limit(this.limits).round();
                    }
                }
                break;
            case STATES.ADD_REGION_FIRST:
                if (this.start) {
                    dist = Coordinate.squareDistance(this.start, point);
                    if (this.activeElement && this.activeElement instanceof MapPolygon && dist > HYSTERESIS) {
                        this.state = STATES.ADD_REGION;
                        this.activeElement.addPoint(this.toSvgSpace(point));
                        this.root.forceUpdate();
                    }
                }
                break;
            case STATES.ADD_REGION:
                if (this.activeElement && this.activeElement instanceof MapPolygon) {
                    var idx = this.activeElement.points.length - 1;
                    this.activeElement.movePoint(this.toSvgScale(delta), idx);
                    this.root.forceUpdate();
                }
                break;
            default:
        }
        this.last = point;
    };
    /**
     * Handles when the user ends their interaction with the Map.
     * @param e The triggering event.
     */
    RLMapEditor.prototype.onGestureUp = function (e) {
        // Convert the coordinate to SVG coordinate space.
        var point = coordinateFromEvent(e, this.root);
        switch (this.state) {
            case STATES.GESTURE_DOWN:
                if (this.targetElement) {
                    if (this.targetElement !== this.activeElement) {
                        this._setActiveElement(this.targetElement);
                    }
                }
                else {
                    this._clearActiveElement();
                    this.elementDeselected.emit(this.activeElement);
                }
                this.state = STATES.NORMAL;
                break;
            case STATES.DRAGGING:
                var delta = Coordinate.difference(point, this.last);
                if (this.activeElement && this.activeElement instanceof MapPolygon && this.targetControl !== undefined) {
                    this.activeElement.movePoint(this.toSvgScale(delta), this.targetControl / 2);
                    this.elementUpdated.emit(this.mapElementFromParsedElement(this.activeElement));
                }
                else if (this.targetElement && this.activeElement &&
                    this.activeElement.id === this.targetElement.id) {
                    // Move the targeted element, if there is one.
                    this.activeElement.move(this.toSvgScale(delta));
                    this.elementUpdated.emit(this.mapElementFromParsedElement(this.activeElement));
                }
                else {
                    // Move the canvas otherwise.
                    if (this.limits) {
                        this.svgTransform = Coordinate.sum(this.svgTransform, delta).limit(this.limits).round();
                    }
                }
                this.state = STATES.NORMAL;
                break;
            case STATES.ADD_REGION_FIRST:
                if (this.activeElement && this.activeElement instanceof MapPolygon) {
                    this.activeElement.addPoint(this.toSvgSpace(point));
                    this.state = STATES.ADD_REGION;
                }
                break;
            case STATES.ADD_REGION:
                if (this.activeElement && this.activeElement instanceof MapPolygon) {
                    if (this.targetControl === 0) {
                        // Remove the last point, it was used as a placeholder for drawing
                        // a line to the cursor.
                        this.activeElement.removePoint();
                        this.state = STATES.NORMAL;
                        this.root.forceUpdate();
                        this.elementCreated.emit(this.mapElementFromParsedElement(this.activeElement));
                    }
                    else {
                        // Add a new point to the active controls array.
                        this.activeElement.addPoint(this.toSvgSpace(point));
                    }
                }
                break;
            case STATES.ADD_POINT:
                if (this.activeElement && this.activeElement instanceof MapMarker && this.root) {
                    this.activeElement.position = this.toSvgSpace(point);
                    this.state = STATES.NORMAL;
                    this.root.forceUpdate();
                    this.elementCreated.emit(this.mapElementFromParsedElement(this.activeElement));
                }
            default:
        }
        this.targetControl = undefined;
        this.targetElement = undefined;
    };
    /**
     * Handles when the user leaves the bounds of the Map entirely.
     * @param e The triggering event.
     */
    RLMapEditor.prototype.onMouseLeave = function (e) {
        if (this.state === STATES.DRAGGING ||
            this.state === STATES.GESTURE_DOWN) {
            this.state = STATES.NORMAL;
            var point = coordinateFromEvent(e, this.root);
            if (this.state === STATES.DRAGGING && this.activeElement) {
                var delta = Coordinate.difference(point, this.last);
                if (this.activeElement && this.activeElement instanceof MapPolygon && this.targetControl !== undefined) {
                    this.activeElement.movePoint(this.toSvgScale(delta), this.targetControl);
                    this.elementUpdated.emit(this.mapElementFromParsedElement(this.activeElement));
                }
                else if (this.targetElement && this.activeElement &&
                    this.activeElement.id === this.targetElement.id) {
                    // Move the targeted element, if there is one.
                    this.activeElement.move(this.toSvgScale(delta));
                    this.elementUpdated.emit(this.mapElementFromParsedElement(this.activeElement));
                }
                else {
                    // Move the canvas otherwise.
                    if (this.limits !== undefined) {
                        this.svgTransform = Coordinate.sum(this.svgTransform, delta).limit(this.limits).round();
                    }
                }
                this.state = STATES.NORMAL;
            }
        }
    };
    RLMapEditor.prototype.onDoubleClick = function (e) {
        if (this.state === STATES.NORMAL) {
            var id = getTargetId(e.target);
            if (id !== undefined) {
                this.elementDoubleClicked.emit(this.elements[id]);
            }
        }
    };
    /**
     * Handles when the window is resized.
     */
    RLMapEditor.prototype.onResize = function () {
        var _this = this;
        clearTimeout(this.resizeDebounce);
        this.resizeDebounce = setTimeout(function (_) {
            // Use a 150ms delay to debounce multiple resize calls and effectively
            // perform the resize action only when the user is 'done' resizing.
            _this.computeSvgSize();
            _this.computeScale();
            _this.limits = _this.computeLimits();
            _this.svgTransform = _this.svgTransform.clone().limit(_this.limits);
        }, 150);
    };
    /**
     * Handles when the user performs a mouse wheen event.  The Map will be zoomed
     * in or out depending on the direction of the wheel.
     *
     * @param e The triggering event.
     */
    RLMapEditor.prototype.onWheel = function (e) {
        var _this = this;
        var oldPos = this.toSvgSpace(new Coordinate(e.clientX, e.clientY));
        if (e.deltaY < 0) {
            if (this.svgScale * 1.05263157895 < this.initialScale * this.maxScale) {
                this.svgScale *= 1.05263157895;
            }
        }
        else {
            if (this.svgScale * 0.95 > this.initialScale * this.minScale) {
                this.svgScale *= 0.95;
            }
        }
        this.limits = this.computeLimits();
        this.processedElements.forEach(function (el) { return el.scale = _this.svgScale; });
        var newPos = this.toSvgSpace(new Coordinate(e.clientX, e.clientY));
        var delta = Coordinate.difference(newPos, oldPos).scale(this.svgScale);
        this.svgTransform.translate(delta).limit(this.limits).round();
    };
    /**
     * Handle when the user pressses the Enter key.
     * @param e The triggering event
     */
    RLMapEditor.prototype.onEnter = function (e) {
        if (e.key === 'enter' && e.target && e.target instanceof SVGElement &&
            (e.target.classList.contains('rl-svg__polygon') ||
                e.target.classList.contains('rl-svg__marker'))) {
            var id_2 = Number(e.target.id);
            var el = this.processedElements.find(function (i) { return i.id === id_2; });
            this._setActiveElement(el);
        }
    };
    /**
     * Add a new `MapRegion` to the map. Calling this method starts the process.
     * The user must then click numerous times on the map to add points.  Only
     * when clicking again on the original point is the region added.
     */
    RLMapEditor.prototype.addRegion = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                this._clearActiveElement();
                this.state = STATES.ADD_REGION_INIT;
                this.activeElement = new MapPolygon();
                this.activeElement.open = true;
                this.activeElement.scale = this.svgScale;
                this.processedElements = this.processedElements.concat([this.activeElement]);
                return [2 /*return*/];
            });
        });
    };
    /**
     * Add a new `MapPoint` element to the map.  Calling this method starts the
     * process.  The user must then click somewhere on the map to add the point.
     */
    RLMapEditor.prototype.addPoint = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                this._clearActiveElement();
                this.state = STATES.ADD_POINT;
                this.activeElement = new MapMarker();
                this.processedElements = this.processedElements.concat([this.activeElement]);
                return [2 /*return*/];
            });
        });
    };
    /**
     * Cancels the current action and returns the map to its default state, ready
     * for futher action.
     */
    RLMapEditor.prototype.cancelAction = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                this._clearActiveElement();
                this.state = STATES.NORMAL;
                return [2 /*return*/];
            });
        });
    };
    /**
     * Removes the currently active element.  If no element is selected when
     * this method is called, it has no effect.
     */
    RLMapEditor.prototype.deleteRegion = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (this.state === STATES.NORMAL && this.activeElement !== undefined) {
                    this.elementDeleted.emit(this.elements[this.activeElement.id]);
                    this._clearActiveElement();
                }
                return [2 /*return*/];
            });
        });
    };
    /**
     * Sets the element with the specified ID to active.
     *
     * @param id The ID of the element to set as active.
     */
    RLMapEditor.prototype.setActiveElement = function (id) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (this.processedElements.length > 0) {
                    this._setActiveElement(this.processedElements.find(function (i) { return i.id === id; }));
                }
                return [2 /*return*/];
            });
        });
    };
    /**
     * Generates a `MapElement` object based on the values in the corresponding
     * `ParsedElement` object.
     *
     * @param el The ParsedElement to convert back to a MapElement
     */
    RLMapEditor.prototype.mapElementFromParsedElement = function (el) {
        var originalEl = this.elements[el.id] || {
            altText: '',
            description: '',
            details: undefined,
            floorId: 0,
            iconPath: [],
            enabled: true,
        };
        return {
            altText: originalEl.altText,
            description: originalEl.description,
            details: originalEl.details,
            enabled: originalEl.enabled,
            floorId: originalEl.floorId,
            id: el.id,
            icon: originalEl.icon,
            symbol: originalEl.symbol,
            name: el.name,
            points: el instanceof MapPolygon ? encodeCoordinates(el.points) : encodeCoordinates(el.position),
        };
    };
    /**
     * Clears the currently active element.
     */
    RLMapEditor.prototype._clearActiveElement = function () {
        if (this.activeElement) {
            this.activeElement.active = false;
        }
        this.activeElement = undefined;
    };
    /**
     * Updates the limits used to restrict the how far the SVG transform can be
     * moved keeping the map from being panning beyond the edge of the image.
     */
    RLMapEditor.prototype.computeLimits = function () {
        var _a = this, imgSize = _a.imgSize, size = _a.size;
        if (imgSize !== undefined) {
            return computeLimits(imgSize, size, this.svgScale);
        }
        else {
            return new DOMRect(0, 0, 1, 1);
        }
    };
    /**
     * Computes the scale factor needed to resize the full map image to be as
     * large as possible, and cropping it vertically/horizontally so no empty
     * space exists if the container has different aspect from the image. This is
     * like CSS `background-size: cover` or SVG `aspectRatio xMidYMid slice`.
     */
    RLMapEditor.prototype.computeScale = function () {
        var _this = this;
        var _a = this, imgSize = _a.imgSize, size = _a.size;
        if (imgSize === undefined) {
            this.svgScale = this.initialScale = 1;
        }
        else {
            this.svgScale = this.initialScale =
                Math.max(size.width / imgSize.width, size.height / imgSize.height);
        }
        this.processedElements.forEach(function (el) { return el.scale = _this.svgScale; });
    };
    RLMapEditor.prototype.computeSvgSize = function () {
        var svg = this.root.querySelector('svg');
        if (svg) {
            var rect = svg.getBoundingClientRect();
            this.size = { width: rect.width, height: rect.height };
        }
    };
    /**
     * Sets the currently active element of the Map.
     *
     * @param el The Element that will be set as the active element.
     */
    RLMapEditor.prototype._setActiveElement = function (el) {
        if (!el) {
            this._clearActiveElement();
            this.elementDeselected.emit();
            return;
        }
        this._clearActiveElement();
        this.activeElement = el;
        this.activeElement.active = true;
        // if (this.elements !== undefined) {
        this.elementSelected.emit(this.elements[this.activeElement.id]);
        // }
    };
    /**
     * Scales a given `Coordinate` by the inverse of the current `svgScale`.
     * Returns a new `Coordinate` with its values scaled and rounded.
     * @param c A `Coordinate` scale.
     */
    RLMapEditor.prototype.toSvgScale = function (c) {
        return c.clone().scale(1 / this.svgScale).round();
    };
    /**
     * Converts a given `Coordinate` object in screen coordinate space to SVG
     * coordinate space.
     * @param c A `Coordinate` to convert to SVG coordinate space.
     */
    RLMapEditor.prototype.toSvgSpace = function (c) {
        return Coordinate.difference(this.toSvgScale(c), this.toSvgScale(this.svgTransform));
    };
    RLMapEditor.prototype.hostData = function () {
        return {
            class: {
                'rl-map-editor': true,
            },
        };
    };
    RLMapEditor.prototype.__stencil_render = function () {
        var m = [
            this.svgScale, 0, 0, this.svgScale,
            this.svgTransform.x,
            this.svgTransform.y,
        ];
        var matrix = 'matrix(' + m.join(',') + ')';
        var elements = this.processedElements.map(function (el) { return el.render(); });
        var controls = this.activeElement !== undefined && this.activeElement instanceof MapPolygon && this.activeElement.renderControls();
        return (h("svg", { class: "rl-svg" }, h("g", { transform: matrix }, h("image", { xlinkHref: this.mapImage !== undefined ? this.mapImage : undefined }), controls ? [elements, controls] : elements)));
    };
    Object.defineProperty(RLMapEditor.prototype, "root", {
        get: function () { return getElement(this); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RLMapEditor, "watchers", {
        get: function () {
            return {
                "elements": ["onElementsChanged"],
                "mapImage": ["onMapImageChanged"]
            };
        },
        enumerable: true,
        configurable: true
    });
    RLMapEditor.prototype.render = function () { return h(Host, this.hostData(), this.__stencil_render()); };
    Object.defineProperty(RLMapEditor, "style", {
        get: function () { return ".rl-map-editor{display:inline-block;overflow:hidden}.rl-map-editor,.rl-map-editor__svg,.rl-svg{width:100%;height:100%}.rl-svg__marker--clickable:hover rect,.rl-svg__marker:focus rect{outline:none;fill:var(--rl-map-element-focus-fill,rgba(255,255,83,.3))}.rl-svg__marker--clickable:hover rect{cursor:pointer}.rl-svg__marker text{font-size:var(--rl-svg__text-size,48px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.rl-svg__polygon{fill:var(--rl-svg__polygon-fill,rgba(0,76,155,.6));stroke:var(--rl-svg__polygon-fill,#004c9b);stroke-width:4}.rl-svg__polygon--activated,.rl-svg__polygon:focus{outline:none;fill:var(--rl-map-element-focus-fill,rgba(255,255,83,.3))}.rl-svg__polygon--activated{stroke:var(--rl-map-element-active-stroke,#c7ab00);stroke-width:8}.rl-svg__polygon:hover{outline:none;fill:var(--rl-map-element-focus-fill,rgba(255,255,83,.3));cursor:pointer}.rl-svg__polygon-outline{fill:none;stroke:var(--rl-map-element-active-stroke,#c7ab00);stroke-width:2}.rl-svg__polygon path{outline:none}.rl-svg__rect{fill:var(--rl-map-region-fill,rgba(0,76,155,.6));stroke:var(--rl-map-region-fill,#004c9b);stroke-width:4}.rl-svg__rect--activated{outline:none;stroke:var(--rl-map-element-active-stroke,#c7ab00);stroke-width:8}.rl-svg__symbol{fill:var(--rl-svg__symbol-fill,rgba(0,76,155,.6));stroke:var(--rl-svg__symbol-fill,#004c9b);stroke-width:1;fill-rule:evenodd}.rl-svg__symbol--alt{fill:var(--rl-svg__symbol-fill-alt,rgba(255,255,83,.5));stroke:var(--rl-svg__symbol-fill-alt,#c7ab00)}.rl-svg__control{stroke:#000;fill:hsla(0,0%,100%,.6);stroke-width:2}.rl-svg__control:hover{fill:hsla(0,0%,75.3%,.6);cursor:pointer}.rl-svg__midpoint{stroke:rgba(0,0,0,.6);fill:hsla(0,0%,100%,.3);stroke-width:2}.rl-svg__midpoint:hover{fill:hsla(0,0%,75.3%,.3);cursor:pointer}"; },
        enumerable: true,
        configurable: true
    });
    return RLMapEditor;
}());
export { RLMapEditor as rl_map_editor };
