import { iMapMarkerOptions } from '../interface';
import { Coordinate } from '../utils/coordinate';
import { MapElement } from './map-element';
import { MarkerIcon } from './marker-icon';
import { MarkerSymbol } from './marker-symbol';
/**
 * A type of `MapElement`.  A marker is an image or text rendered at a specific
 * point on a Map.
 */
export declare class MapMarker extends MapElement {
    _anchor: Coordinate;
    /**
     * An offset relative to the `position` of the marker.
     */
    anchor: Coordinate;
    _available: boolean;
    /**
     * A flag indicating if the this `MapMarker` represents an active or inactive
     * point.  When the marker is available, it gets a matching `--available` CSS
     * class added.
     */
    available: boolean;
    _icon?: MarkerIcon | MarkerSymbol;
    /**
     * The icon that will be drawn for this `MapMarker`.
     */
    icon: undefined | MarkerIcon | MarkerSymbol;
    _label: string;
    /**
     * A line of text dispayed on the map either on its own as a simple text
     * label or along side the `icon`.
     */
    label: string;
    _opacity: number;
    /**
     * The opacity of the marker, 1 being fully opaque and 0 being fully
     * transparent.
     */
    opacity: number;
    _position: Coordinate;
    /**
     * The overall position of the marker on the `Map`.
     */
    position: Coordinate;
    constructor(opts?: iMapMarkerOptions);
    /**
     * Moves this marker by a given amount.
     * @param delta The amount to move by
     */
    move(delta: Coordinate): void;
    render(): any;
}
