import { Coordinate } from '../utils/coordinate';
import { MapElement } from './map-element';
/**
 * A type of `MapElement`.  A polygon is a shape drawn onto a `Map` based on a
 * path consisting of three or more `Coordinates`.
 */
export declare class MapPolygon extends MapElement {
    _open: boolean;
    /**
     * If set to true, this `MapPolygon` is not automatically closed.
     */
    open: boolean;
    /**
     * A string in SVG Path notation used to draw this `MapPolygon`.
     */
    _path: string;
    _points: Coordinate[];
    /**
     * An array of `Coordinate`s that correspond to the points of this `MapPolygon`.
     */
    points: Coordinate[];
    /**
     * Add a new point to the array of points that represent this `MapRegion`.
     * @param c The `Coordinate` representing the point to add
     * @param index The index where the point should be added.  If not specified,
     * adds the point at the end
     */
    addPoint(c: Coordinate, index?: number): void;
    /**
     * Move this `MapRegion` by a specified offset.
     * @param delta The amount to move by
     */
    move(delta: Coordinate): void;
    /**
     * Move a single point of this `MapRegion` by a specified amount.
     * @param delta The amount to move by
     * @param index The index of the point to move
     */
    movePoint(delta: Coordinate, index: number): void;
    /**
     * Remove a point from the array of points that represent this `MapRegion`.
     * If no index is specified, the last point is removed.
     * @param index The index of the point to remove
     */
    removePoint(index?: number): void;
    /**
     * Renders the `MapPolygon`.
     */
    render(): any;
    /**
     * Generates the DOM necessary to display the control points for this
     * `MapElement`.  There are control points at the median and endpoint of each
     * edge.  This allows any point of the `MapElement` to be moved as well as new
     * point created on each line.
     */
    renderControls(): any[] | undefined;
}
