import { Coordinate } from '../utils/coordinate';
/**
 * Predefined map Symbols.
 */
export declare enum MarkerSymbolPaths {
    computer = "M 8 36 c -2 0 -4 -2 -4 -4 v -20 c 0 -2 2 -4 4 -4 h 32 c 2 0 4 2 4 4 v 20 c 0 2 -2 4 -4 4 h 8 v 4 h -48 v -4 z M 8 12 h 32 v 20 h -32 z"
}
interface Size {
    height: number;
    width: number;
}
/**
 * A styled vector path displayed as the icon of a `MapMarker`.
 */
export declare class MarkerSymbol {
    _alt: boolean;
    /**
     * A flag indicating if this symbol should use an alternate style.
     */
    alt: boolean;
    _anchor: Coordinate;
    /**
     * The position of the symbol relative to the marker.
     */
    anchor: Coordinate;
    _path: MarkerSymbolPaths | string;
    /**
     * The symbol's path specified using a built-in string or a custom path
     * expressed using SVG path notation.
     */
    path: MarkerSymbolPaths | string;
    /**
     * The name of the path.  This is appended to the class added to the path and
     * allows for custom styling based on each type of path.
     */
    _pathName: string;
    _rotation: number;
    /**
     * The angle by which to rotate the symbol, expressed clockwise in degrees.
     */
    rotation: number;
    _size: Size;
    /**
     * The size of the symbol
     */
    size: Size;
    /**
     * Renders the DOM necessary to display this symbol.
     */
    render(): any;
}
export {};
