import { MapElementDetail, MapElementDetailType } from '../../interface';
/**
 * An entry to be displayed as part of a `DetailDialog`.
 */
export declare class DetailDialogItem {
    private index;
    private itemId;
    /**
     * A flag indicating that this item will be removed when all the details are
     * serialized and sent to the server.
     */
    remove: boolean;
    /**
     * The description for this item.
     */
    description: string;
    /**
     * The name of this item.
     */
    name: string;
    /**
     * Alternate text for this item.
     */
    altText: string;
    /**
     * The ID of the detail type of this item.
     */
    detailTypeId: number;
    /**
     * The short code of this item.
     */
    code: string;
    /**
     * The currently selected category.
     */
    categorySelection: number;
    /**
     * All the possible values for the type of this `DetailDialogItem`.
     */
    typeOptions: MapElementDetailType[];
    /**
     * The currently selected item Type.
     */
    typeSelection: number;
    /**
     * The `MapElementDetail` that this item is displaying the information of.
     */
    detail?: MapElementDetail;
    onDetailChanged(): void;
    /**
     * An array of all the different categories that can be selected.
     */
    categoryOptions: {
        name: string;
        id: number;
        items: MapElementDetailType[];
    }[];
    onCategoryOptionsChanged(): void;
    updateCategory(newIndex: number): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    /**
     * Returns a `Promise` that resolves to a `MapElementDetail` object with
     * values set as those of this `DetailDialogItem`.
     */
    getDetail(): Promise<MapElementDetail>;
    /**
     * Returns a `Promise` that resolves to whether or not this `DetailDialogItem`
     * is to be removed or not.
     */
    toRemove(): Promise<boolean>;
    hostData(): {
        class: {
            'rl-detail-dialog-item': boolean;
            'rl-detail-dialog-item--removed': boolean;
        };
        id: string;
    };
    render(): any[];
}
