import { EventEmitter } from '../../stencil.core';
import { MapElementDetail, MapElementDetailMap, MapElementDetailType } from '../../interface';
export declare class DetailDialog {
    /**
     * Internal index used to differentiate multiple dialogs.
     */
    private index;
    /**
     * Reference to the Material Dialog underlying this `DetailDialog`.
     */
    private dialog;
    /**
     * Array of the child `DetailDialogItem` elements.
     */
    private detailItems;
    /**
     * Internal root of this component.
     */
    root: HTMLElement;
    /**
     * The title of the dialog window.
     */
    dialogTitle: string;
    /**
     * An array of strings that will be used to create action buttons for the
     * dialog.  When the corresponding button is clicked by the user, MDCDialog
     * will emit an event with the lowercase version of the action. For example
     * the action `Yes` would emit the `MDCDialog:closing` with the property
     * `event.detail.action === 'yes'`.
     */
    dialogActions: string[];
    /**
     * The details that will be displayed in this dialog.
     */
    details?: MapElementDetailMap;
    /**
     * The different categories that each item can display.  Each category has
     * a set of Detailtypes.
     */
    categories: {
        name: string;
        id: number;
        items: MapElementDetailType[];
    }[];
    /**
     * An event emitted when a new `DetailDialogItem` is added to the dialog.
     */
    addDetail: EventEmitter;
    componentDidLoad(): void;
    /**
     * Opens this dialog.
     */
    open(): Promise<void>;
    /**
     * Returns the values of all the DetailDialogItems as an array of
     * `MapElementDetails`
     */
    getDetails(): Promise<MapElementDetail[]>;
    hostData(): {
        class: {
            'mdc-dialog': boolean;
            'rl-detail-dialog': boolean;
        };
        role: string;
        'aria-modal': string;
        'aria-labelledby': string;
        'aria-describedby': string;
    };
    render(): any[];
}
