import { EventEmitter } from '../../stencil.core';
/**
 * A component that wraps a `Material Text Field` component.
 */
export declare class TextField {
    /**
     * Internal ID used to differentiate multiple text fields.
     */
    readonly id: number;
    /**
     * The root element of this component.
     */
    root: HTMLElement;
    /**
     * The supplemental label for the text field.
     */
    label: string;
    /**
     * A flag indicating if the text field has an outlined style.
     */
    outlined: boolean;
    /**
     * A flag indicating if the text field is disabled and does not allow user
     * input.
     */
    disabled: boolean;
    /**
     * A flag indicating if the text field uses the full-width style.
     */
    fullwidth: boolean;
    /**
     * A flag indicating if the text field uses a textarea instead of an input.
     */
    textarea: boolean;
    /**
     * Additional text displayed below the main text field.
     */
    helperText: string;
    /**
     * The current value of the text field input or text area.
     */
    value: string;
    /**
     * An icon displayed within the text field.
     */
    icon: string;
    /**
     * The location of the icon displayed within the text field.
     */
    iconLocation: 'trailing' | 'leading';
    /**
     * An event emitted when the value of the input or textarea changes.
     */
    changeValue: EventEmitter;
    componentDidLoad(): void;
    hostData(): {
        class: {
            'rl-text-field': boolean;
            'mdc-text-field': boolean;
            'mdc-text-field--outlined': boolean;
            'mdc-text-field--disabled': boolean;
            'mdc-text-field--fullwidth': boolean;
            'mdc-text-field--textarea': boolean;
            'mdc-text-field--with-leading-icon': boolean;
            'mdc-text-field--with-trailing-icon': boolean;
        };
    };
    render(): any[];
}
