import { Coordinate } from './coordinate';
/**
 * Moves a given array of `Coordinate`s by a specified distance in the
 * x and y axes.
 * @param c A `Coordinate` or `Coordinate`s to move.
 * @param dx A `Coordinate` to use for the translate values, or a number to move
 * in the x-axis;
 * @param dy The distance to move in the y-axis.
 */
export declare function movePoints(c: Coordinate[], dx: number | Coordinate, dy?: number): Coordinate[];
/**
 * Replaces an item in a given array with a new one.
 *
 * @param array The array to replace the item in.
 * @param index The index of the item to replace.
 * @param item The new item to place at `index`.
 */
export declare function arrayReplace(array: any[], index: number, item: any): any[];
/**
 * Creates a new Coordinate based on the clientX/Y values of a given event or the
 * top-left corner of an element.  Optionally gets the position relative to a
 * second element.
 *
 * @param e The event to retrieve the client coordinates from.
 */
export declare function coordinateFromEvent(a: any, b?: any): Coordinate;
/**
 * Parses a string of x/y coordinate pairs separated by spaces.  Returns an
 * object with two properties.  The `points` property is an array of Coordinate
 * objects representing each x/y pair and the `path` property is an SVG encoded
 * path string in the form `M x1 y1 L x2 y2 ... L xN yN Z`.
 *
 * @param data A string of space-separated coordinates.
 */
export declare function decodeCoordinates(data: string, closed: boolean): {
    path: string;
    points: Coordinate | Coordinate[];
};
/**
 * Turns an array of Coordinate objects into a single space-separated string.
 * @param points An array of Coordinates.
 */
export declare function encodeCoordinates(points: Coordinate[] | Coordinate): string;
/**
 * Generates an SVG-style path string from an array of `Coordinates`.
 *
 * @param points An array of `Coordinates`.
 * @param open If the path represented by the array of points is open or closed.
 */
export declare function pathFromCoordinateArray(points: Coordinate[], open?: boolean): string;
export declare function isSVGPath(str: string): boolean;
